---
tags:
  - prompt
author: agp
source:
- ^[0-2].*
- ^3[0-1].*
---

# Prompt

Consider the implemented documents from previous iterations (specs/iter-xx where xx is a number lower then the folder where this file is located).

Consider the code generated by previous iterations as well, in order not to coding features that are already implemented.

Now, consider the new documents located in the same directory as this file as well.

Organize the documents documents from current iteration only (from 001.xxx to 319.xxx) to generate a consistent specification document that group all aspects of the application creating a nested hierarchy of specifications that goes from higher level to smaller and fine level.

Skip any feature that is already implemented or that is not relevant to the current iteration.

1. Write the result in a new file named `325.spec.results.md`.
2. User Markdown format with bulleted ticks (tasks) to organize the specifications.
3. Write an extra file `326.spec.considerations.md` with a detailed explanation of the specifications, including any assumptions, constraints, and dependencies.
